You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by er...@apache.org on 2013/06/20 13:24:05 UTC

git commit: [flex-sdk] [refs/heads/develop] - Working on getting the AIR and mobile tests to run on the VM (part 5).

Updated Branches:
  refs/heads/develop fe2ebca16 -> 3c5d20de0


Working on getting the AIR and mobile tests to run on the VM (part 5).

Signed-off-by: Erik de Bruin <er...@ixsoftware.nl>


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/3c5d20de
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/3c5d20de
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/3c5d20de

Branch: refs/heads/develop
Commit: 3c5d20de071fa4f26a6821aae78804babe633ff5
Parents: fe2ebca
Author: Erik de Bruin <er...@ixsoftware.nl>
Authored: Thu Jun 20 13:22:30 2013 +0200
Committer: Erik de Bruin <er...@ixsoftware.nl>
Committed: Thu Jun 20 13:22:30 2013 +0200

----------------------------------------------------------------------
 mustella/jenkins.sh | 63 ++++++++++++++++++++++++++++++++----------------
 1 file changed, 42 insertions(+), 21 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/3c5d20de/mustella/jenkins.sh
----------------------------------------------------------------------
diff --git a/mustella/jenkins.sh b/mustella/jenkins.sh
index 1a4373c..65db071 100755
--- a/mustella/jenkins.sh
+++ b/mustella/jenkins.sh
@@ -35,40 +35,61 @@ set -o igncr
 
 
 
+MAIN_FAILED=false
+AIR_FAILED=false
+MOBILE_FAILED=false
+
+
+
 # MAIN
 #sh ./mini_run.sh -timeout=60000 -all
 
 #if [[ -s failures.txt ]] ; then
 #  echo "Some tests failed: running '-failures'" 
 #  sh ./mini_run.sh -timeout=60000 -failures
 #else
 #  echo "All main tests passed on first run" 
 #fi ;
 
+
+
 # AIR
-#sh ./mini_run.sh -apollo tests/apollo
+sh ./mini_run.sh -apollo tests/apollo
+
+if [[ -s failures.txt ]] ; then
+  echo "Some AIR tests failed: running '-apollo -failures'" 
+  sh ./mini_run.sh -apollo -failures
+  if [[ -s failures.txt ]] ; then
+    AIR_FAILED=true
+  else
+    echo "All AIR tests passed after running '-apollo -failures'" 
+  fi ;
+else
+  echo "All AIR tests passed on first run" 
+fi ;
+
+
+
+# MOBILE
+#cat > local.properties <<END 
+#target_os_name=android
+#android_sdk=C:/ApacheFlex/dependencies/AndroidSDK/adt-bundle-windows-x86_64-20130522/sdk
+#runtimeApk=${AIR_HOME}/runtimes/air/android/emulator/Runtime.apk
+#device_name=win
+#END
+
+#sh ./mini_run.sh -mobile tests/mobile
 
 #if [[ -s failures.txt ]] ; then
-#  echo "Some AIR tests failed: running '-failures'" 
-#  sh ./mini_run.sh -failures
+#  echo "Some mobile tests failed: running '-mobile -failures'" 
+#  sh ./mini_run.sh -mobile -failures
 #else
-#  echo "All AIR tests passed on first run" 
+#  echo "All mobile tests passed on first run" 
 #fi ;
 
-# MOBILE
-rm -f local.properties
-cat > local.properties <<END 
-target_os_name=android
-android_sdk=C:/ApacheFlex/dependencies/AndroidSDK/adt-bundle-windows-x86_64-20130522/sdk
-runtimeApk=${AIR_HOME}/runtimes/air/android/emulator/Runtime.apk
-device_name=win
-END
+#rm -f local.properties
 
-sh ./mini_run.sh -mobile tests/mobile
-
-if [[ -s failures.txt ]] ; then
-  echo "Some mobile tests failed: running '-failures'" 
-  sh ./mini_run.sh -failures
-else
-  echo "All mobile tests passed on first run" 
-fi ;
+if $AIR_FAILED ; then
+  echo "Some of the 'main' tests have failed, even after running '-failures'..."
+  exit 1
+fi ;
\ No newline at end of file
@@ -35,40 +35,61 @@ set -o igncr
 
 #if [[ -s failures.txt ]] ; then
-#  echo "Some tests failed: running '-failures'" 
+#  echo "Some 'main' tests failed: running '-failures'" 
 #  sh ./mini_run.sh -timeout=60000 -failures
 #else